# remove bogus auto-requires
%global __requires_exclude pear\\(xapian.*\\)

%define with_php 0

%global _default_patch_fuzz 2

%ifarch %mips %arm
%define build_java 0
%else
%define build_java 1
%endif
%ifarch %mips
%define build_mono 0
%else
%define build_mono 1
%endif

Summary:	Bindings for the Xapian
Name:		xapian-bindings
Version:	1.4.23
Release:	%mkrel 2
License:	GPLv2+
Group:		Development/Other
URL:		https://www.xapian.org/
Source0:	https://www.oligarchy.co.uk/xapian/%{version}/%{name}-%{version}.tar.xz
BuildRequires:	pkgconfig(xapian-core) >= %{version}
BuildRequires:	pkgconfig(python3)
BuildRequires:	python3dist(sphinx)
BuildRequires:	python3dist(setuptools)
%if %with_php
BuildRequires:	php-devel
BuildRequires:	php-cli
%endif
BuildRequires:	pkgconfig(tcl)
%if %build_java
BuildRequires:	java-devel
BuildRequires:	javapackages-tools
%endif
BuildRequires:	pkgconfig(ruby)
BuildRequires:	pkgconfig(lua)
%if %build_mono
BuildRequires:	pkgconfig(mono)
%endif
BuildRequires:	libtool
BuildRequires:	autoconf

%description
SWIG and JNI bindings allowing Xapian to be used from various
other programming languages.

%if %build_java
%package java
Summary:	Files needed for developing Java applications which use Xapian
Group:		Development/Java
Requires:	xapian >= %{version}
Requires:	java

%description java
This package provides the files needed for developing Java applications which
use Xapian.
%endif

%package lua
Summary:	Files needed for developing lua scripts which use Xapian
Group:		Development/PHP
Requires:	xapian >= %{version}
Requires:	lua%{lua_version}

%description lua
This package provides the files needed for developing
lua scripts which use Xapian.

%if %build_mono
%package mono
Summary:	Files needed for developing C# applications which use Xapian
Group:		Development/C#
Requires:	xapian >= %{version}
Requires:	mono-core

%description mono
This package provides the files needed for developing
C# applications which use Xapian.
%endif

%if %with_php
%package php
Summary:	Files needed for developing PHP scripts which use Xapian
Group:		Development/PHP
Requires:	xapian >= %{version}
Requires:	php

%description php
This package provides the files needed for developing
PHP scripts which use Xapian.
%endif

%package -n python3-%{name}
Summary:	Files needed for developing Python 3 scripts which use Xapian
Group:		Development/Python
Requires:	xapian >= %{version}
Requires:	python3
%{?python_provide:%python_provide python3-%{name}}

%description -n python3-%{name}
This package provides the files needed for developing
Python 3 scripts which use Xapian.

%package ruby
Summary:	Files needed for developing Ruby applications which use Xapian
Group:		Development/Ruby
Requires:	xapian >= %{version}
Requires:	ruby

%description ruby
This package provides the files needed for developing
Ruby applications which use Xapian.

%package tcl
Summary:	Files needed for developing TCL scripts which use Xapian
Group:		Development/Other
Requires:	xapian >= %{version}
Requires:	tcl

%description tcl
This package provides the files needed for developing
TCL scripts which use Xapian.

%prep
%setup -q
%autopatch -p1

# There is no sphinx.main in Sphinx 2
sed -i 's/sphinx\.main/sphinx.cmd.build.main/g' $(grep -r 'sphinx\.main' -l)
sed -i 's/import sphinx/import sphinx.cmd.build/g' $(grep -r 'import sphinx' -l)

# Trick Python 2 to build docs by Python 3
sed -i 's/$PYTHON2 -c '"'"'import sphinx/python3 -c '"'"'import sphinx/' configure configure.ac
sed -i 's/PYTHONPATH=..:$$PYTHONPATH $(OSX_SIP_HACK_ENV) $(PYTHON2)/PYTHONPATH=..:$$PYTHONPATH $(OSX_SIP_HACK_ENV) python3/' python/Makefile.am python/Makefile.in

%build
# (tpg) do not check for this, to much effort to provide a patch
%define Werror_cflags %nil

# We want to avoid using jni.h from libgcj-devel, so we force
# the includedir instead of using ./configure detection, which would
# default to libgcj jni.h:
# - Anssi (12/2007)
export CPPFLAGS="%{optflags} -I%{java_home}/include"
export JDK_HOME=%{java_home}
export TCL_LIB=%{tcl_sitearch}
export LUA_INC=%{_includedir}
export LUA_LIB=%{lua_libdir}
export RUBY_LIB=%{ruby_vendorlibdir}
export RUBY_LIB_ARCH=%{ruby_vendorarchdir}

autoreconf -fiv

%configure \
%if %build_mono
	--with-csharp \
%endif
	--with-lua \
%if %with_php
	--with-php7 \
%endif
	--with-python3 \
	--with-ruby \
	--with-tcl \
%if %build_java
	--with-java
%endif


%make_build

%install
%make_install jnidir=%{_libdir}

%if %build_java
# Install the needed jar file as well
install -d -m755 %{buildroot}%{_jnidir}
install -m644 java/built/xapian.jar %{buildroot}%{_jnidir}
%endif

%if %build_java
%files java
%doc %{_docdir}/xapian-bindings/java
%{_libdir}/libxapian_jni.so
%{_jnidir}/xapian.jar
%endif

%files lua
%doc %{_docdir}/xapian-bindings/lua
%{lua_libdir}/xapian.so

%if %build_mono
%files mono
%doc %{_docdir}/xapian-bindings/csharp
%{_libdir}/_XapianSharp.so
%{_libdir}/mono/XapianSharp/XapianSharp.dll
%{_libdir}/mono/gac/XapianSharp/%{version}*/XapianSharp.dll
%endif

%if %with_php
%files php
%doc %{_docdir}/xapian-bindings/php
%{_libdir}/php/extensions/xapian.so
%{_datadir}/php/xapian.php
%endif

%files -n python3-%{name}
%doc %{_docdir}/xapian-bindings/python3
%dir %{python3_sitearch}/xapian
%{python3_sitearch}/xapian/*.py*
%{python3_sitearch}/xapian/*.so
%{python3_sitearch}/xapian/__pycache__/*

%files ruby
%doc %{_docdir}/xapian-bindings/ruby
%{ruby_vendorarchdir}/_xapian.so
%{ruby_vendorlibdir}/xapian.rb

%files tcl
%doc %{_docdir}/xapian-bindings/tcl8
%{tcl_sitearch}/xapian%{version}/



%changelog
* Thu Dec 28 2023 daviddavid <daviddavid> 1.4.23-2.mga10
+ Revision: 2023087
- rebuild for py3.12

* Tue Sep 05 2023 daviddavid <daviddavid> 1.4.23-1.mga10
+ Revision: 1984527
- new version: 1.4.23

* Fri Aug 05 2022 luigiwalser <luigiwalser> 1.4.20-1.mga9
+ Revision: 1875445
- 1.4.20

* Sat May 07 2022 luigiwalser <luigiwalser> 1.4.19-1.mga9
+ Revision: 1856629
- 1.4.19

* Fri Apr 01 2022 umeabot <umeabot> 1.4.18-4.mga9
+ Revision: 1838705
- Mageia 9 Mass Rebuild

* Mon Feb 14 2022 tmb <tmb> 1.4.18-3.mga9
+ Revision: 1774823
- rebuild for python 3.10

* Mon Apr 05 2021 wally <wally> 1.4.18-2.mga9
+ Revision: 1713490
- rebuild for lua 5.4

* Thu Apr 01 2021 daviddavid <daviddavid> 1.4.18-1.mga9
+ Revision: 1712264
- new version: 1.4.18

* Tue Mar 23 2021 daviddavid <daviddavid> 1.4.17-3.mga9
+ Revision: 1708117
- rebuild for python 3.9

* Sun Dec 27 2020 daviddavid <daviddavid> 1.4.17-2.mga8
+ Revision: 1664102
- build without php support for now (not yet compatible with php8)

* Wed Oct 14 2020 luigiwalser <luigiwalser> 1.4.17-1.mga8
+ Revision: 1636019
- 1.4.17

* Fri Feb 21 2020 umeabot <umeabot> 1.4.14-2.mga8
+ Revision: 1547799
- Mageia 8 Mass Rebuild

* Mon Feb 10 2020 daviddavid <daviddavid> 1.4.14-1.mga8
+ Revision: 1488436
- new version: 1.4.14
+ wally <wally>
- replace deprecated %%configure2_5x

* Thu Oct 17 2019 daviddavid <daviddavid> 1.4.13-1.mga8
+ Revision: 1454271
- new version: 1.4.13

* Fri Oct 11 2019 daviddavid <daviddavid> 1.4.12-1.mga8
+ Revision: 1451406
- new version: 1.4.12

* Wed Sep 25 2019 daviddavid <daviddavid> 1.4.11-3.mga8
+ Revision: 1445776
- rebuild for python3.8
- drop python2 support
- fix mono dependency

* Fri Aug 23 2019 daviddavid <daviddavid> 1.4.11-2.mga8
+ Revision: 1431387
- remove python2-sphinx BR

* Sat Jul 06 2019 daviddavid <daviddavid> 1.4.11-1.mga8
+ Revision: 1418992
- new version: 1.4.11

* Tue Feb 12 2019 daviddavid <daviddavid> 1.4.10-1.mga7
+ Revision: 1365441
- new version: 1.4.10

* Tue Jan 08 2019 daviddavid <daviddavid> 1.4.9-2.mga7
+ Revision: 1352818
- rebuild for new Python 3.7

* Mon Nov 19 2018 daviddavid <daviddavid> 1.4.9-1.mga7
+ Revision: 1331913
- new version: 1.4.9

* Sun Sep 23 2018 umeabot <umeabot> 1.4.7-2.mga7
+ Revision: 1301797
- Mageia 7 Mass Rebuild

* Tue Aug 14 2018 daviddavid <daviddavid> 1.4.7-1.mga7
+ Revision: 1251586
- new version: 1.4.7

* Tue Aug 07 2018 wally <wally> 1.4.6-2.mga7
+ Revision: 1248806
- restore pycache

* Tue Jul 17 2018 daviddavid <daviddavid> 1.4.6-1.mga7
+ Revision: 1244059
- new version: 1.4.6

* Fri Jul 06 2018 daviddavid <daviddavid> 1.4.5-4.mga7
+ Revision: 1242143
- update files list (no more __pycache__ reference)

* Tue Apr 17 2018 daviddavid <daviddavid> 1.4.5-3.mga7
+ Revision: 1219668
- fix a bogus auto-requires on pear(xapian.php)

* Tue Apr 17 2018 daviddavid <daviddavid> 1.4.5-2.mga7
+ Revision: 1219600
- new version: 1.4.5
- enable python3 bindings
- enable lua bindings
- enable php7 support
- rename xapian-bindings-python to python2-xapian-bindings

* Mon Dec 05 2016 luigiwalser <luigiwalser> 1.2.24-1.mga6
+ Revision: 1072662
- 1.2.24

* Wed Feb 17 2016 umeabot <umeabot> 1.2.12-14.mga6
+ Revision: 963472
- Mageia 6 Mass Rebuild

* Sun Dec 27 2015 tv <tv> 1.2.12-13.mga6
+ Revision: 916024
- rebuild for mono4

* Wed Oct 15 2014 umeabot <umeabot> 1.2.12-12.mga5
+ Revision: 740157
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 1.2.12-11.mga5
+ Revision: 730733
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 1.2.12-10.mga5
+ Revision: 690540
- Mageia 5 Mass Rebuild
+ pterjan <pterjan>
- Rebuild for new Python

* Thu Jan 09 2014 dmorgan <dmorgan> 1.2.12-8.mga4
+ Revision: 565753
- Add fedora patch to fix ruby check
- Rebuild against current java stack
+ umeabot <umeabot>
- Mageia 4 Mass Rebuild
+ luigiwalser <luigiwalser>
- update java BRs

* Mon Mar 18 2013 rtp <rtp> 1.2.12-4.mga3
+ Revision: 403939
- Modify spec to allow building without java/mono and disable java on arm

* Mon Jan 14 2013 umeabot <umeabot> 1.2.12-3.mga3
+ Revision: 386436
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sat Oct 20 2012 malo <malo> 1.2.12-2.mga3
+ Revision: 308561
- update RPM group

* Thu Sep 13 2012 dmorgan <dmorgan> 1.2.12-1.mga3
+ Revision: 293598
- New version
- Rebuild against Java7
+ tv <tv>
- new release

* Mon Jul 18 2011 dmorgan <dmorgan> 1.2.6-2.mga2
+ Revision: 125667
- Fix xapian requires
- Fix java requires

* Mon Jul 18 2011 dmorgan <dmorgan> 1.2.6-1.mga2
+ Revision: 125570
- Update to 1.2.6
  Disable php package ( does not build )
+ ennael <ennael>
- remove buildroot definition
- imported package xapian-bindings


* Sun May 08 2011 Tomasz Pawel Gajc <tpg@mandriva.org> 1.2.5-1mdv2011.0
+ Revision: 672574
- update to new version 1.2.5
- fix file list

* Wed Nov 17 2010 Funda Wang <fwang@mandriva.org> 1.2.3-3mdv2011.0
+ Revision: 598309
- fix link with languages

* Wed Nov 17 2010 Funda Wang <fwang@mandriva.org> 1.2.3-2mdv2011.0
+ Revision: 598299
- rebuild for py2.7

* Sun Aug 29 2010 Tomasz Pawel Gajc <tpg@mandriva.org> 1.2.3-1mdv2011.0
+ Revision: 574209
- update to new version 1.2.3

* Fri Jul 23 2010 Tomasz Pawel Gajc <tpg@mandriva.org> 1.2.2-1mdv2011.0
+ Revision: 557318
- update to new version 1.2.2
- rediff patch 0
- update file list

* Mon Apr 26 2010 Tomasz Pawel Gajc <tpg@mandriva.org> 1.0.19-1mdv2010.1
+ Revision: 539272
- update to new version 1.0.19

* Sun Nov 22 2009 Tomasz Pawel Gajc <tpg@mandriva.org> 1.0.17-1mdv2010.1
+ Revision: 469121
- update to new version 1.0.17

* Mon Oct 05 2009 Guillaume Rousse <guillomovitch@mandriva.org> 1.0.16-2mdv2010.0
+ Revision: 454328
- fix dependencies

* Mon Sep 14 2009 Tomasz Pawel Gajc <tpg@mandriva.org> 1.0.16-1mdv2010.0
+ Revision: 440610
- update to new version 1.0.16

* Mon Aug 31 2009 Tomasz Pawel Gajc <tpg@mandriva.org> 1.0.15-1mdv2010.0
+ Revision: 422741
- update to new version 1.0.15

* Thu Jul 30 2009 Frederik Himpe <fhimpe@mandriva.org> 1.0.14-1mdv2010.0
+ Revision: 404785
- Disable parallel build in order to fix out of memory errors in Java
- update to new version 1.0.14

* Fri Jun 19 2009 Tomasz Pawel Gajc <tpg@mandriva.org> 1.0.13-1mdv2010.0
+ Revision: 387404
- update to new version 1.0.13

* Sat May 09 2009 Tomasz Pawel Gajc <tpg@mandriva.org> 1.0.12-1mdv2010.0
+ Revision: 373748
- update to new version 1.0.12
- drop patch 1
- fix file list for mono subpackage

* Sun Jan 11 2009 Funda Wang <fwang@mandriva.org> 1.0.10-1mdv2009.1
+ Revision: 328220
- fix building

  + Tomasz Pawel Gajc <tpg@mandriva.org>
    - update to new version 1.0.10
    - use %%define Werror_cflags %%nil, as providing a patch for this would take some time

* Fri Dec 05 2008 Adam Williamson <awilliamson@mandriva.org> 1.0.9-2mdv2009.1
+ Revision: 310409
- rebuild for new tcl
- move tcl bindings to new location per policy

* Tue Nov 04 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 1.0.9-1mdv2009.1
+ Revision: 299653
- update to new version 1.0.9

* Fri Sep 05 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 1.0.8-1mdv2009.0
+ Revision: 281117
- update to new version 1.0.8

* Sat Jul 19 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 1.0.7-1mdv2009.0
+ Revision: 238697
- drop patch 0
- update to new version 1.0.7

* Tue Apr 22 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 1.0.6-1mdv2009.0
+ Revision: 196589
- Patch0: fix tcllibdir
- fix file list
- drop patch0, merged upstream
- new version

  + Thierry Vignaud <tv@mandriva.org>
    - fix no-buildroot-tag
    - fix description-line-too-long

* Fri Dec 28 2007 Anssi Hannula <anssi@mandriva.org> 1.0.5-1mdv2008.1
+ Revision: 139004
- install java files properly
- fix java build

  + Tomasz Pawel Gajc <tpg@mandriva.org>
    - provide patch 0 (fixes ruby docs install)
    - try to use java-1.7.0-icedtea
    - new version

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Tue Oct 30 2007 Tomasz Pawel Gajc <tpg@mandriva.org> 1.0.4-1mdv2008.1
+ Revision: 103798
- new version

* Sun Oct 14 2007 Funda Wang <fwang@mandriva.org> 1.0.3-1mdv2008.1
+ Revision: 98138
- fix ruby bindings dir
- New version 1.0.3

* Sun Jul 08 2007 Tomasz Pawel Gajc <tpg@mandriva.org> 1.0.2-1mdv2008.0
+ Revision: 49877
- own missing file
- new version

* Thu Jun 14 2007 Tomasz Pawel Gajc <tpg@mandriva.org> 1.0.1-1mdv2008.0
+ Revision: 39741
- fix file list
- new version

* Thu May 24 2007 Tomasz Pawel Gajc <tpg@mandriva.org> 1.0.0-2mdv2008.0
+ Revision: 30520
- fix requires

* Wed May 23 2007 Tomasz Pawel Gajc <tpg@mandriva.org> 1.0.0-1mdv2008.0
+ Revision: 30319
- Import xapian-bindings

